from .wsseheader import WsseToken

from .__version__ import __title__, __description__, __url__, __version__
from .__version__ import  __author__, __author_email__, __license__
from .__version__ import __copyright__


